Register at Forums - Mtbr.com
Description: Mountain bike discussion and forum
Keywords: mountain bike reviews discussion forum

- Register
- Remember Me?

# Registration ## Register at Forums - Mtbr.com ### The Facebook Platform ### Required Information User Name: Please enter the name by which you would like to log-in and be known on this site. Password: Confirm Password: Please enter a password for your user account. Note that passwords are case-sensitive. Email Address: Confirm Email Address: Please enter a valid email address for yourself. In order to fight spam, users with emails that are not confirmed within 24 hours will be deleted PlayThru Human Verification: ### Additional Required Information (profile) First Name: Strictly confidential. For admin purposes only, not viewable by other members. Last Name: Strictly confidential. For admin purposes only, not viewable by other members. From (City, State or Country): Where ya from pardner? Favorite type of riding (can choose more than: What kind of riding do you like best? Bike Setup: What is the bike build of your main bike ### Additional Information Time Zone: All timestamps displayed on the forums can be automatically corrected to show the correct time for your location in the world. Simply select the appropriate time zone from the list below. DST Correction Option: In addition, you may set the appropriate option to allow for daylight savings time in your part of the world. Receive Email... Receive Email from Administrators Receive Email from Other Members From time to time, the administrators and/or other members may want to send you email notifications or messages. If you do not want to receive email from certain people then you may disable the options here ## Forum Rules In order to proceed, you must agree with the following rules: Forum Rules Registration to this forum is free! We do insist that you abide by the rules and policies detailed below. If you agree to the terms, please check the 'I agree' checkbox and press the 'Complete Registration' button below. If you would like to cancel the registration, click here to return to the forums index. Although the administrators and moderators of Forums - Mtbr.com will attempt to keep all objectionable messages off this site, it is impossible for us to review all messages. All messages express the views of the author, and neither the owners of Forums - Mtbr.com, nor vBulletin Solutions, Inc. (developers of vBulletin) will be held responsible for the content of any message. By agreeing to these rules, you warrant that you will not post any messages that are obscene, vulgar, sexually-oriented, hateful, threatening, or otherwise violative of any laws. The owners of Forums - Mtbr.com reserve the right to remove, edit, move or close any content item for any reason. I have read, and agree to abide by the Forums - Mtbr.com rules.